Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(797)

Unified Diff: chrome/browser/chromeos/policy/user_cloud_external_data_manager.h

Issue 58313002: Removed the PolicyDefinitionList. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@chrome-policy-schema-10-use-registry
Patch Set: rebase Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/policy/user_cloud_external_data_manager.h
diff --git a/chrome/browser/chromeos/policy/user_cloud_external_data_manager.h b/chrome/browser/chromeos/policy/user_cloud_external_data_manager.h
index fa5a5231fca573410e0221028c975f7f0f5c1456..4e1910d8d522b6f77a8e53052a59086fbfb79e59 100644
--- a/chrome/browser/chromeos/policy/user_cloud_external_data_manager.h
+++ b/chrome/browser/chromeos/policy/user_cloud_external_data_manager.h
@@ -9,6 +9,7 @@
#include "base/files/file_path.h"
#include "base/memory/ref_counted.h"
#include "chrome/browser/chromeos/policy/cloud_external_data_manager_base.h"
+#include "components/policy/core/common/policy_details.h"
namespace base {
class SequencedTaskRunner;
@@ -17,7 +18,6 @@ class SequencedTaskRunner;
namespace policy {
class CloudPolicyStore;
-struct PolicyDefinitionList;
class ResourceCache;
// Downloads, verifies, caches and retrieves external data referenced by
@@ -27,14 +27,14 @@ class ResourceCache;
// because no other platform has policies referencing external data.
class UserCloudExternalDataManager : public CloudExternalDataManagerBase {
public:
// The |policy_definitions| are used to determine the maximum size that the
// data referenced by each policy can have. Download scheduling, verification,
// caching and retrieval tasks are done via the |backend_task_runner|, which
// must support file I/O. Network I/O is done via the |io_task_runner|. The
// manager is responsible for external data references by policies in
// |policy_store|.
UserCloudExternalDataManager(
- const PolicyDefinitionList* policy_definitions,
+ const GetChromePolicyDetailsCallback& get_policy_details,
scoped_refptr<base::SequencedTaskRunner> backend_task_runner,
scoped_refptr<base::SequencedTaskRunner> io_task_runner,
const base::FilePath& cache_path,
@@ -27,14 +27,14 @@ class ResourceCache;
class UserCloudExternalDataManager : public CloudExternalDataManagerBase {
public:
- // The |policy_definitions| are used to determine the maximum size that the
+ // |get_policy_details| is used to determine the maximum size that the
// data referenced by each policy can have. Download scheduling, verification,
// caching and retrieval tasks are done via the |backend_task_runner|, which

Powered by Google App Engine
This is Rietveld 408576698